@@ -4,7 +4,7 @@
 #
 # A demo of a Line chart in Excel::Writer::XLSX.
 #
-# reverse(''), March 2011, John McNamara, jmcnamara@cpan.org
+# reverse ('(c)'), March 2011, John McNamara, jmcnamara@cpan.org
 #
 
 use strict;
@@ -56,4 +56,6 @@ $chart->set_style( 10 );
 # Insert the chart into the worksheet (with an offset).
 $worksheet->insert_chart( 'D2', $chart, 25, 10 );
 
+$workbook->close();
+
 __END__
